# Ceres Documentation

Welcome to the Ceres documentation! This documentation provides detailed information on various
modules, Bill of Materials (BoM) versions, and usage guidelines for the Ceres Android library.

## Table of Contents

1. [Modules](#modules)
2. [Bill of Materials (BoM)](#bill-of-materials)
3. [Version Catalog](#version-catalog)

---

## Modules

Ceres is organized into multiple modules, each serving a specific purpose. These modules can be
included selectively in your Android project to streamline development. Here are the available
modules:

- [Backup](reference.md): The Backup module provides essential utilities for data backup
  and recovery.
- [Core](reference.md): The core module provides essential utilities and foundation for
  Ceres.
- [Data](reference.md): The data module offers data-related functionality for Ceres.
- [Firebase](reference.md): Integrate Firebase services seamlessly with Ceres.
- [Framework](reference.md): Get access to framework-level components and features.
- [Monetisation](reference.md): Monetize your Android app using the Monetisation
  module.
- [Navigation](reference.md): Efficiently handle app navigation with the Navigation
  module.
- [Screen](reference.md): Simplify screen management and UI with the Screen module.
- [UI](reference.md): Enhance your app's user interface using the UI module.

Each module documentation provides in-depth information on its features and how to integrate it into
your project.

---

## Bill of Materials

The Bill of Materials (BoM) simplifies library version management by providing a centralized
mechanism to manage versions across Ceres modules. Learn how to use the BoM in your project by
referring to the [BoM documentation](releases.md).

- [BoM Versions](releases.md): Explore the available BoM versions and their release dates.

---

## Version Catalog

The Ceres Version Catalog provides implementation details of Ceres libraries and BoM versions in
TOML format. It helps you manage library versions effortlessly. Refer to
the [Version Catalog](ceres-version-catalog.md) to understand how to declare dependencies using the
latest versions and access implementation details.

---

We hope this documentation helps you make the most of the Ceres Android library. If you have any
questions or need further assistance, feel free to reach out to us. Happy coding!

**Getting Started**

To get started with Xenoglot, refer to the comprehensive documentation available at
[source.teogor.dev/ceres](https://source.teogor.dev/ceres). The documentation provides
detailed explanations, examples, and best practices for using the library effectively.

## Find this repository useful? 🩷

* Support it by joining __[stargazers](https://github.com/teogor/ceres/stargazers)__ for this
  repository. 📁
* Get notified about my new projects by __[following me](https://github.com/teogor)__ on GitHub. 💻
* Interested in sponsoring me? [Support me](sponsor.md) on GitHub! 🤝
