/*
 * Copyright 2023 teogor (Teodor Grigor)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package dev.teogor.ceres.ui.foundation.lib.tools.di

import android.app.Activity
import android.util.Log
import android.view.Window
import androidx.metrics.performance.JankStats
import dagger.Module
import dagger.Provides
import dagger.hilt.InstallIn
import dagger.hilt.android.components.ActivityComponent

@Module
@InstallIn(ActivityComponent::class)
object JankStatsModule {
  @Provides
  fun providesOnFrameListener(): JankStats.OnFrameListener {
    return JankStats.OnFrameListener { frameData ->
      // Make sure to only log janky frames.
      if (frameData.isJank) {
        // We're currently logging this but would better report it to a backend.
        Log.v("Ceres Jank", frameData.toString())
      }
    }
  }

  @Provides
  fun providesWindow(activity: Activity): Window {
    return activity.window
  }

  @Provides
  fun providesJankStats(
    window: Window,
    frameListener: JankStats.OnFrameListener,
  ): JankStats {
    return JankStats.createAndTrack(window, frameListener)
  }
}
